@@ -12,7 +12,8 @@ import os.path as osp
 import sys
 
 # Local imports
-from spyder.config.base import _, running_in_ci, is_conda_based_app
+from spyder.api.translations import _
+from spyder.config.base import running_in_ci, is_conda_based_app
 from spyder.utils import programs
 
 
@@ -58,7 +59,7 @@ PYGITHUB_REQVER = '>=2.3.0'
 PYGMENTS_REQVER = '>=2.0'
 PYLINT_REQVER = '>=3.1,<4'
 PYLINT_VENV_REQVER = '>=3.0.2'
-PYLSP_REQVER = '>=1.13.0,<1.14.0'
+PYLSP_REQVER = '>=1.13.2,<1.14.0'
 PYLSP_BLACK_REQVER = '>=2.0.0,<3.0.0'
 PYLSP_RUFF_REQVER = '>=2.3.0,<3.0.0'
 PYLS_SPYDER_REQVER = '>=0.4.0'
@@ -71,8 +72,8 @@ QTAWESOME_REQVER = '>=1.4.0,<1.5.0'
 QTCONSOLE_REQVER = '>=5.7.0,<5.8.0'
 QTPY_REQVER = '>=2.4.0'
 RTREE_REQVER = '>=0.9.7'
-SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=3.1.0,<3.2.0'
+SPHINX_REQVER = '>=7.2.0'
+SPYDER_KERNELS_REQVER = '>=3.1.2,<3.2.0'
 SUPERQT_REQVER = '>=0.6.2,<1.0.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
